package com.ruoyi.logistics.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.common.core.constant.ServiceNameConstants;
import com.ruoyi.logistics.domain.RptFinancialMonthSummary;
import com.ruoyi.system.api.factory.RemoteFileFallbackFactory;
import org.springframework.cloud.openfeign.FeignClient;

/**
 * 财务月度汇总Service接口
 * 
 * @author RuiJing
 * @date 2026-01-29
 */

public interface IRptFinancialMonthSummaryService 
{
    /**
     * 查询财务月度汇总
     * 
     * @param summaryId 财务月度汇总主键
     * @return 财务月度汇总
     */
    public RptFinancialMonthSummary selectRptFinancialMonthSummaryBySummaryId(Long summaryId);

    /**
     * 查询财务月度汇总列表
     * 
     * @param rptFinancialMonthSummary 财务月度汇总
     * @return 财务月度汇总集合
     */
    public List<RptFinancialMonthSummary> selectRptFinancialMonthSummaryList(RptFinancialMonthSummary rptFinancialMonthSummary);

    /**
     * 新增财务月度汇总
     * 
     * @param rptFinancialMonthSummary 财务月度汇总
     * @return 结果
     */
    public int insertRptFinancialMonthSummary(RptFinancialMonthSummary rptFinancialMonthSummary);

    /**
     * 修改财务月度汇总
     * 
     * @param rptFinancialMonthSummary 财务月度汇总
     * @return 结果
     */
    public int updateRptFinancialMonthSummary(RptFinancialMonthSummary rptFinancialMonthSummary);

    /**
     * 批量删除财务月度汇总
     * 
     * @param summaryIds 需要删除的财务月度汇总主键集合
     * @return 结果
     */
    public int deleteRptFinancialMonthSummaryBySummaryIds(Long[] summaryIds);

    /**
     * 删除财务月度汇总信息
     * 
     * @param summaryId 财务月度汇总主键
     * @return 结果
     */
    public int deleteRptFinancialMonthSummaryBySummaryId(Long summaryId);

    int creatMontSummary(Map param);

    List<RptFinancialMonthSummary> selectRptFinancialMonthSummaryListToCheck(RptFinancialMonthSummary rptFinancialMonthSummary);

    public int updateRptFinancialMonthSummaryByInvoice(RptFinancialMonthSummary rptFinancialMonthSummary);

    int creatMontSummaryAccountAdjustment(Map param);

    boolean verification(String monthCode, String deptId);

    void creatMontSummaryZero(Map param);
}
